@@ -2,20 +2,8 @@ from struct import unpack
 import socket
 from asyncio import shield
 import asyncio
-import math
-import errno
-from functools import reduce
 
-import sys
-import time
-import datetime
-
-from pathlib import Path
-import os
-from basic_logtools.filelog import LogFile
-
-from networktools.time import timestamp, now
-from networktools.library import my_random_string
+from networktools.time import timestamp
 
 from networktools.colorprint import rprint, bprint
 
@@ -31,20 +19,22 @@ Updated to python3.5 by David Pineda @pineiden dpineda@csn.uchile.cl
 '''
 
 try:
-    from .gsof_settings import gsof_field_names, gsof_rec, gsof_table_names, logfile
+    from .gsof_settings import gsof_field_names, gsof_rec, gsof_table_names
 except Exception:
-    from gsof_settings import gsof_field_names, gsof_rec, gsof_table_names, logfile
+    from gsof_settings import gsof_field_names, gsof_rec, gsof_table_names
+
 
 def checksum256(data_check):
     """Calculate checksum"""
     # ord: string -> unicode int
     # map(a,b): opera a en b
     # list entrega lista o arrays
-     #formula: 	(Status + type + length + data bytes) modulo 256
+    # formula: 	(Status + type + length + data bytes) modulo 256
     data_bytes = data_check.get("DATA_BYTES")
     checksum = data_check.get("CHECKSUM")
-    chk256  = sum(data_bytes) % 256
-    return  checksum == chk256
+    chk256 = sum(data_bytes) % 256
+    return checksum == chk256
+
 
 class Gsof(BaseProtocol):
     """ Class to connect to tcp port and parse GSOF messages """
@@ -59,7 +49,6 @@ class Gsof(BaseProtocol):
         self.tables = gsof_table_names
         # manage asyncronous clients
 
-
     async def get_message_header(self, idc):
         # receive data from source
         # max amount of data
@@ -75,9 +64,10 @@ class Gsof(BaseProtocol):
 
         try:
             if writer.transport.is_closing():
-                self.logger.error("La conexión se cerró %s" % writer)
+                self.logger.error(f"La conexión se cerró {writer}")
                 self.status = False
-                raise Exception("Conexión perdida para idc %s station %s" %(idc, self.station))
+                raise Exception(
+                    f"Conexión perdida para idc {idc} station {self.station}")
             data = None
 
             try:
@@ -85,44 +75,43 @@ class Gsof(BaseProtocol):
                 self.msg_dict = dict(zip(
                     msg_field_names,
                     unpack('>' + str(bufsize) + 'B', data)))
-                campos_unpack =unpack('>%dB'%bufsize, data)
+                campos_unpack = unpack('>%dB' % bufsize, data)
                 self.msg_dict = dict(zip(msg_field_names, campos_unpack))
                 status = self.msg_dict['STATUS']
                 bin_status = bin(status)
                 batt_status = bin_status[3]
                 self.msg_dict["LOW_BATTERY"] = bool(int(batt_status))
-                self.msg_bytes = await shield(self.readbytes(reader,self.msg_dict['LENGTH']-3))
+                self.msg_bytes = await shield(self.readbytes(reader, self.msg_dict['LENGTH']-3))
                 self.msg_0 = self.msg_bytes
                 n = 2
-                check_etx =  await shield(self.readbytes(reader, n))
+                check_etx = await shield(self.readbytes(reader, n))
                 (checksum, etx) = unpack('>2B', check_etx)
-                self.data_check["CHECKSUM"] = checksum                
+                self.data_check["CHECKSUM"] = checksum
                 self.data_check["DATA_BYTES"] = list(self.msg_bytes+data[1:])
                 self.checksum = checksum256(self.data_check)
                 self.msg_dict["CHECKED"] = self.checksum
             except asyncio.TimeoutError as te:
-                self.logger.exception("Get message TimeoutError, %s"%te)
+                self.logger.exception("Get message TimeoutError, %s" % te)
                 return False
             except asyncio.IncompleteReadError as ir:
-                print("Incomplete read on set header", reader, n)
-                self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+                print(f"Incomplete read on set header {reader}, {n} bytes")
+                self.logger.exception(
+                    f"Station {self.station}, Tiempo fuera al no poder leer en readbytes {n} bytes, {ir}")
                 return False
             except socket.timeout as timeout:
                 self.logger.exception(
-                    "La conexión se cerró, socket timeout %s, STATION %S" % (timeout, self.station))
+                    f"La conexión se cerró, socket timeout {timeout}, STATION {self.station}")
                 self.on_blocking()
                 self.logger.exception("Esperando mucho tiempo")
                 self.status = False
                 return False
             except Exception as ex:
-                print("Escepcion as ex: %s" %ex)
+                print("Escepcion as ex: %s" % ex)
                 self.logger.exception(
-                    "La conexión se cerró, error en comunicación %s" % ex)
+                    f"La conexión se cerró, error en comunicación {ex}")
                 await self.close(idc)
                 self.on_blocking()
-                info = "Error %s en estación %s. Encabezado con data %s" % (
-                    ex, self.station, data)
-                print(info)
+                info = f"Error {ex} en estación {self.station}. Encabezado con data {data}"
                 self.logger.info(info)
                 self.logger.error(ex)
                 self.status = False
@@ -130,10 +119,10 @@ class Gsof(BaseProtocol):
             return True
 
         except asyncio.IncompleteReadError as e:
-            self.logger.exception("Error de mensaje incompleto %s" % e)
+            self.logger.exception(f"Error de mensaje incompleto {e}")
             self.logger.error(
-                "Error de mensaje esperado en n bytes %s" % e.expected)
-            self.logger.error("Error de mensaje recibido %s" % e.partial)
+                f"Error de mensaje esperado en n bytes {e.expected}")
+            self.logger.error(f"Error de mensaje recibido {e.partial}")
             raise e
 
         except socket.timeout:
@@ -144,22 +133,20 @@ class Gsof(BaseProtocol):
 
         except socket.error as ex:
             self.close()
-            print("Error de conexión %s error %s" % (self.station, ex))
             self.logger.error(ex)
             self.sock = self.create_socket(None)
             self.on_blocking()
             raise ex
 
     async def get_records(self):
-        msg = {}        
+        msg = {}
         while self.msg_bytes:
             # READ THE FIRST TWO BYTES FROM RECORD HEADER
             try:
                 record_type, record_length = unpack('>2B', self.msg_bytes[0:2])
             except Exception as ex:
                 self.status = False
-                qex = "Error %s en estación %s, tabla %s" % (
-                    ex, self.station, 'Header')
+                qex = f"Error {ex} en estación {self.station}, tabla Header"
                 self.logger.debug(qex)
                 return False, {}
             self.msg_bytes = self.msg_bytes[2:]
@@ -169,10 +156,9 @@ class Gsof(BaseProtocol):
             except Exception as ex:
                 self.status = False
                 self.logger.error(ex)
-                print("No hay mensaje que traducir")
                 self.logger.error("Desconectando debido a error en mensaje")
                 self.logger.error(
-                    "Reconectando debido a error en mensaje, luego de desconexión")
+                    f"Reconectando debido a error en mensaje, luego de desconexión, {ex}")
                 self.on_blocking()
                 return False, {}
         msg["HEADER"] = self.msg_dict
@@ -187,7 +173,7 @@ class Gsof(BaseProtocol):
         timestamp = self.timestamp
         try:
             rec_field_names = field_names.get(record_type)
-            if not record_type in [13, 14, 33, 48] and record_type in field_names.keys():
+            if record_type not in [13, 14, 33, 48] and record_type in field_names.keys():
                 # print("Base recibida")
                 try:
                     rec_values = unpack(
@@ -198,7 +184,7 @@ class Gsof(BaseProtocol):
                     self.msg_bytes = self.msg_bytes[record_length:]
                 except Exception as ex:
                     self.status = False
-                    self.logger.exception("Error al hacer unpack",ex)
+                    self.logger.exception(f"Error al hacer unpack {ex}")
                     raise ex
 
             elif record_type in [13, 14, 33, 48] and record_type in field_names.keys():
@@ -242,5 +228,3 @@ class Gsof(BaseProtocol):
             self.status = False
             raise ex
         return {table_name: msg}
-
-
